.. _packages_label:

Packages
========

Under the umbrella of oemof, several libraries for energy system modelling are collected.
Each specialised for a certain task.
The most recognised library `oemof-solph <https://oemof-solph.readthedocs.io>`_ is used to model energy system with LP/MILP. It can be fed with demand data from the `demandlib <https://demandlib.readthedocs.io>`_ and feedin timeseries from the `feedinlib <https://feedinlib.readthedocs.io>`_.
`TESPy <https://tespy.readthedocs.io>`_ provides in-depth modelling of thermal energy systems.
`oemof-thermal <https://oemof-thermal.readthedocs.io>`_ extends `oemof-solph <https://oemof-solph.readthedocs.io>`_ components with LP/MILP modelled thermal components.
`CyDeTS <https://github.com/oemof/cydets>`_ can be used to detect storage cycles.
The libraries share common principles, similar APIs, and are at least partially interoperable.

Projects with stable releases
-----------------------------

.. csv-table:: 
   :header: "Package", "Description", "Links"
   :widths: 15, 70, 15 
   :file: packages.csv


Projects in an early state
--------------------------

The following projects are in an early stage of development and might change frequently.

.. csv-table:: 
   :header: "Package", "Description", "Links"
   :widths: 15, 70, 15 
   :file: packages_early_stage.csv


.. |zenodo_oemof-solph| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.596235
   :width: 54px

.. |github_oemof-solph| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/oemof-solph
   :height: 24px

.. |zenodo_oemof-thermal| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.3606384
   :width: 54px

.. |github_oemof-thermal| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/oemof-thermal
   :height: 24px

.. |zenodo_cydets| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.2625698
   :width: 54px

.. |github_cydets| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/cydets
   :height: 24px

.. |zenodo_demandlib| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.2553504
   :width: 54px

.. |github_demandlib| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/demandlib
   :height: 24px

.. |zenodo_feedinlib| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.2554101
   :width: 54px

.. |github_feedinlib| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/feedinlib
   :height: 24px

.. |zenodo_tespy| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.2555866
   :width: 54px

.. |github_tespy| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/tespy
   :height: 24px

.. |zenodo_windpowerlib| image:: https://about.zenodo.org/static/img/logos/zenodo-gradient-round.svg
   :target: https://doi.org/10.5281/zenodo.824267
   :width: 54px

.. |github_windpowerlib| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/wind-python/windpowerlib
   :height: 24px

.. |github_dnhx| image:: https://github.githubassets.com/images/modules/logos_page/GitHub-Mark.png
   :target: https://github.com/oemof/dhnx
   :height: 24px
